break

# XMLRésuméLibrary: User Guide

bookTitle | Element Reference | citation

## Name

break — A linebreak

Deprecated

## Synopsis

### Content Model

    EMPTY

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

### Important

This element is deprecated as of XML Résumé Library version 1.3.3. It should not be used.

`break` was introduced to allow linebreaks in free-form addresses, but the stylesheets have been modified so that they don't need an explicit linebreak marker. Instead, linebreaks in source text are formatted as linebreaks in formatted text.

The `break` element indicates a position in text where a linebreak should occur.

### Parents

`break` may be contained in these elements: `address`

## Examples

None.

bookTitle | Element Reference | citation